@@ -2,6 +2,7 @@ import argparse
 from PIL import Image
 
 from transformerocr.tool.detector import TextDetector
+from transformerocr.tool.config import Cfg
 
 def main():
     parser = argparse.ArgumentParser()
@@ -9,8 +10,9 @@ def main():
     parser.add_argument('--config', required=True, help='foo help')
 
     args = parser.parse_args()
+    config = Cfg(args.config)
 
-    detector = TextDetector(args.config)
+    detector = TextDetector(config)
 
     img = Image.open(args.img)
     s = detector.predict(img)
